@@ -238,4 +238,7 @@ sub rel {
     $rel;
 }
 
+# Some URI::URL compatibility stuff
+*epath = \&path;
+
 1;
